;; load locally installed org mode package 
(add-to-list 'load-path "~/src/org-mode/lisp")
(require 'org-install)

(setq dissertation-bib-file "~/Documents/philosophy/dissertation/build/dissertation.bib")

(defun add-headline-to-bib-buffer (bib-buffer)
  "Export headline at point to Bibtex into the given buffer"
  (let ((bib-entry (org-bibtex-headline))
	(custom-id (org-entry-get (point) "CUSTOM_ID")))
    (if (and custom-id bib-entry)
	(with-current-buffer bib-buffer
	  (insert bib-entry)))))
    
(defun export-subtree-to-bib-buffer (headline bib-buffer)
  "Export the entries in the subtree at point to Bibtex into the given buffer."
  (save-excursion
      (goto-char (org-find-exact-headline-in-buffer headline))
      (org-map-entries
       (lambda () (add-headline-to-bib-buffer bib-buffer))
       t ; match: all entries below this one
       'tree ; scope: just this subtree
       )))

(defun reading-list-to-bibtex ()
  "Export 'Reading list' headline in current buffer to dissertation.bib"
  (interactive)
  (let ((org-buffer (current-buffer))
	(bib-buffer (create-file-buffer "dissertation.bib")))
    (export-subtree-to-bib-buffer "Reading list" bib-buffer)
    (with-current-buffer bib-buffer
      (write-file dissertation-bib-file))))
   